/**
 * This file contains configuration of the jQuery Validation plug-in
 * that are general to IHG applications.
 */

/**
 * This section are configurations related to custom validations.
 */

/**
 * Pulled this from this site:  breakingpar.com
 *
 * Had this comment on the page:
 * According to the US government, a valid social security number comes in
 * three groups - a group of 3 numbers,
 * then a group of 2 numbers,
 * then a group of 4 numbers.
 *
 * The first 3 numbers are assigned to individual states, territories,
 * or groups of people. They start with 001, and currently go up to 772.
 * (Although, technically, a lot of those upper numbers haven't been used
 * yet. But since they have been assigned, it is possible they could be
 * used soon).
 *
 * The second group of numbers is 01 through 99. (There's a formula for
 * how they are assigned, starting with the odd numbers 02 through 08,
 * then the even numbers 11 through 99, or something similar to that.
 * But every number 01 through 99 could be possible).
 *
 * The last group of numbers is 0001 through 9999 and are assigned sequentially.
 *
 * @param value The string SSN to test.
 * @return True if it is a valid SSN, false otherwise.
 */
function isValidSSN(value) {
    var re = /^([0-6]\d{2}|7[0-6]\d|77[0-2])([ \-]?)(\d{2})\2(\d{4})$/;
    if (!re.test(value)) { return false; }
    var temp = value;
    if (value.indexOf("-") != -1) { temp = (value.split("-")).join(""); }
    if (value.indexOf(" ") != -1) { temp = (value.split(" ")).join(""); }
    if (temp.substring(0, 3) == "000") { return false; }
    if (temp.substring(3, 5) == "00") { return false; }
    if (temp.substring(5, 9) == "0000") { return false; }
    return true;
}

/**
 * Wrapper function to handle validation of element as optional or not.
 *
 * @param ssn The SSN in string form.
 * @param element The jQuery element.
 * @return True if valid.
 */
function validateSSN(ssn, element) {
    ssn = ssn.replace(/\s+/g, "");
	return this.optional(element) || ssn.length > 8 &&
		isValidSSN(ssn);
}

/**
 * Pulled this from the jQuery Validation site.
 * Supposed to validate for a US phone number.
 *
 * @param phoneNumber The string phone number to validate.
 * @param element The jQuery element so we can check if it is optional.
 * @return True if valid.
 */
function isValidPhoneUS(phoneNumber) {
	return phoneNumber.length == 0
        || (phoneNumber.length > 9
            && phoneNumber.match(/^(1-?)?(\([2-9]\d{2}\)|[2-9]\d{2})-?[2-9]\d{2}-?\d{4}$/));
}

function validatePhoneUS(phoneNumber, element) {
    phoneNumber = phoneNumber.replace(/\s+/g, "");
    return this.optional(element) || isValidPhoneUS(phoneNumber);
}

$.validator.addMethod("phoneUS", validatePhoneUS, getText("phoneUSFieldValidationError", "Invalid phone number"));

$.validator.addMethod("ssn", validateSSN, getText("ssnFieldValidationError", "Invalid SSN"));

/**
 * This section are configurations related to i18n of validation error messages.
 */

$.validator.messages.required = getText("requiredFieldValidationError", "Field required");
$.validator.messages.remote = getText("remoteFieldValidationError", "Field must be remote");
$.validator.messages.email = getText("emailFieldValidationError", "Field must be an email");
$.validator.messages.url = getText("urlFieldValidationError", "Field must be an URL");
$.validator.messages.date = getText("dateFieldValidationError", "Field must be a date");
$.validator.messages.number = getText("numberFieldValidationError", "Field must be a number");
$.validator.messages.digits = getText("digitsFieldValidationError", "Field must be an integer");
$.validator.messages.creditcard = getText("creditcardFieldValidationError", "Field must be a credit card number");
$.validator.messages.equalTo = getText("equalToFieldValidationError", "Field must be equal to another field");
$.validator.messages.accept = getText("acceptFieldValidationError", "Field must be accepted");
$.validator.messages.maxlength = $.validator.format(getText("maxlengthFieldValidationError", "Field exceeded maximum length"));
$.validator.messages.minlength = $.validator.format(getText("minlengthFieldValidationError", "Field was not of minimum length"));
$.validator.messages.rangelength = $.validator.format(getText("rangelengthFieldValidationError", "Field was not in range"));
$.validator.messages.range = $.validator.format(getText("rangeFieldValidationError", "Field was not of in range"));
$.validator.messages.max = $.validator.format(getText("maxFieldValidationError", "Field exceeded maximum value"));
$.validator.messages.min = $.validator.format(getText("minFieldValidationError", "Field was not of minimum value"));

$.validator.setDefaults(
    {
        messages: {
            userid: {
                required: getText("useridRequiredFieldValidationError", "Field required")
            },
            password: {
                required: getText("passwordRequiredFieldValidationError", "Field required")
            }
        }
    }
);
